Chunking stream groups
======================

For an overview, refer to :doc:`recv-chunk-group`. This page is a reference for the
C++ API.

.. doxygenclass:: spead2::recv::chunk_stream_group_config
   :members:

.. doxygenclass:: spead2::recv::chunk_stream_group
   :members:

.. doxygenclass:: spead2::recv::chunk_stream_group_member
   :members:

Ringbuffer convenience API
--------------------------
.. doxygenclass:: spead2::recv::chunk_stream_ring_group
   :members:
